<TS version="2.1" language="mi">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Tikiake matau ki te whakamāori i te kupu whakamāoritanga:
Right-click to edit address or label</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Whakapūmau he wāhitau hōu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Hou</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Kape</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp;Kati</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Mukua te whiriwhiri i te wāhitau kua whiriwhirihia i te rārangi</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Turiwhenua i te wāhitau, ingoa rānei ki te rapu.</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Whakapau kaha te raraunga i te whārangi o nāianei ki tētahi kōnae</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Kaweake</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Whakakore</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Whiriwhiria te wāhitau hei tuku moni ki.</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Whiriwhiria te wāhitau hei whiwhi moni</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Ko ēnei ngā whakamāoritanga mō ō whakamahi Bitcoin hei tuku moni. Tirohia i te moni me te wāhi whiwhi i mua i te tuku i ngā moni.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Ko ēnei ngā whakamāoritanga mō ō whakaaetanga Bitcoin hei whiwhi utu. Whakamahi i te pātene 'Waihanga whakaaronga hōu' i te pae whiwhi ki te whakapūmau i ngā whakaaronga hōu.
Ko te whakakī i ēnei whakaaronga e taea ana anake ki ngā whakararuraru o te momo 'tawhito'.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Tārua wāhitau</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Tātari &amp; Tapanga </translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Whakatika</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Whakaputu Rārangi Wāhitau</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Taputapu whakawhiti kōma</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">I whakapā atu i te hapa i te whakaputa i te rārangi wāhitau ki %1. Whakamātau anō, koa.</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Kore te whakapau kore</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Tapanga</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Wāhitau</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Whakapātai Kōrero</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Whakauru kupu whakapākehā</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Tūtohi hōu</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Tōaitia anō te kupu whakawhitiwhiti hōu</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Whakakino pūtea</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Kia whakapiri tēnei mahi ki tō whakapuaki moni hei whakawhiti i te whare moni.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Whakatangohia te pēke moni</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Whakarerekē kīanga</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Whakamana te whakakītanga pūtea</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Whakatūpato: Ki te whakakino i tō pēke moni me te ngaro i tō kupuhipa, ka &lt;b&gt;NGARO KATOA ŌU PĪNIHA BITCOIN&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Kei te whakapau kaha koe ki te whakakino i to whare moni?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Whakakorengia te wharetaonga</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Whakauruhia te kīangahipa hou mo te putea. Whakamahia he kupu huna kia tekau, neke atu ranei nga tohu matapōkere 2, 3 waru neke atu ranei nga kupu 3</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Whakauru te kupu whakapākehā me te kupu hōu mō te pēke moni.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Mahara kia whakakorehia te whakakino i ō wharepukapuka kia whakararuraru i ō wharepūkoro.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Whakakī i te pēke</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">Kei te whakakorehia tō pēke moni.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Kua whakakītia ināianei tō pēke.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">HEMENGĀ: Me whakakapi ngā tāruarau i mua i te whakaputa i te kōnae pēke whakamahi kē o tō wharemoni ki te kōnae pēke hōu, whakakapi. Hei ētahi take whakamarumaru, ka whakakore ngā tāruarau i mua i te kōnae pēke kore whakakapi, ka whiwhi whakamahi i te kōnae pēke hōu, whakakapi.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Kati te whakamātau i te whakakorenga wharetaonga</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Kua whakakore te whakakītanga pūtea wharetaonga i te whakakoretanga ā-roto. Kāore i whakakītia tō pūtea wharetaonga.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Kāore ngā kupu whakapāhohe i te rite.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Kati te whakakore i te whakatuwhera o te whareparakau</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Ko te kupuhipa i whakauruhia mō te whakapau kōnae whakamāhukihuki, he hē.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character. If this is successful, please set a new passphrase to avoid this issue in the future.</source>
        <translation type="unfinished">Ko te kupu whakapā atu i whakauruhia mō te whakapau kōnae kore tika. Kei roto i te kupu whakapā he pūāhua kore (hei tauira - he tūmomo kore). Ki te whakapau kōnae te kupu whakapā i te wā i whakatūria ai tēnei whakamahi i mua i te 25.0, whakamātau anō ki te whakapau kōnae ki te whakakore i tēnei raruraru i te wā e whai ake nei.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Kua whakarerekētia te kupuhipa pūtea.</translation>
    </message>
    <message>
        <source>Passphrase change failed</source>
        <translation type="unfinished">Kua whakapau kē te whakarerekē i te kupu whakapākehā.</translation>
    </message>
    <message>
        <source>The old passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character.</source>
        <translation type="unfinished">Ko te kupuhipa tawhito i whakauruhia mō te whakamāori i te wharetaonga he hē. Kei roto i te kupuhipa tētahi pūāhua kore (hei tauira - he tīmatanga kore). Ki te whakaritea te kupuhipa ki te whakamahi i tētahi wāhanga o tēnei wharepukapuka i mua i te 25.0, whakamātau anō ki te whakamahi anō me ngā pūāhua ki te — engari kāore i whakauruhia — te pūāhua tuatahi kore.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Whakatūpato: Kei te whakakā te pātuhi Caps Lock!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">IP/NetmaskIP/Netmask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Kati i te wa i whakakore ai</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">Settings file %1 me whakapōrearea, me whakararuraru rānei.</translation>
    </message>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">Tūkino whakawhiti</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">I whakararuraru mate. Ka whakakore %1 i te whakararuraru haumaru, ka whakakore hoki.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Hapa whaiaro</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">Kua puta he hapa ā-roto. Ka whakamātau a %1 ki te whakarite i te whakararuraru i te āhua haere tonu. He hē whakararuraru tēnei e whakapātaitia ana i raro i te whakamārama i raro nei.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Wāhitau</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Tapanga</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Tapanga</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Taputapu whakawhiti kōma</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Tapanga</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Wāhitau</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Kore te whakapau kore</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Kaweake</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Whakapau kaha te raraunga i te whārangi o nāianei ki tētahi kōnae</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Input not found or already spent</source>
        <translation type="unfinished">Kāore i kitea te urupare, kua whiwhi i mua, kua whiwhi rānei.</translation>
    </message>
    <message>
        <source>Insufficient dbcache for block verification</source>
        <translation type="unfinished">Kore rawa i te nui te dbcache mō te whakamātau i te paraka</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation type="unfinished">He iti te whiwhi moni</translation>
    </message>
    <message>
        <source>Invalid -i2psam address or hostname: '%s'</source>
        <translation type="unfinished">Kore whakaaetanga -i2psam wāhitau rite, ingoa wāhi: '%s'</translation>
    </message>
    <message>
        <source>Invalid -onion address or hostname: '%s'</source>
        <translation type="unfinished">Kore whakaaetanga -onion wāhitau, ingoa ranei: '%s'</translation>
    </message>
    <message>
        <source>Invalid -proxy address or hostname: '%s'</source>
        <translation type="unfinished">Kore whakaaetanga -proxy wāhitau ranei ingoa whare: '%s'</translation>
    </message>
    <message>
        <source>Invalid P2P permission: '%s'</source>
        <translation type="unfinished">Invalid P2P whakaaetanga: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for %s=&lt;amount&gt;: '%s' (must be at least %s)</source>
        <translation type="unfinished">He whakararuraru te whiwhinga mō %s = &lt;amount&gt;: '%s' (me whakarite i te mea atu i te %s)</translation>
    </message>
    <message>
        <source>Invalid amount for %s=&lt;amount&gt;: '%s'</source>
        <translation type="unfinished">Kore whiwhinga mō te %s=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -%s=&lt;amount&gt;: '%s'</source>
        <translation type="unfinished">Kore whiwhinga mō te -%s=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid netmask specified in -whitelist: '%s'</source>
        <translation type="unfinished">Kua whakapau kaha te netmask kore whaimana i whakarārangi i roto i te -whitelist: '%s'</translation>
    </message>
    <message>
        <source>Invalid port specified in %s: '%s'</source>
        <translation type="unfinished">Kua whakapātaitia te pōti korewhiwhi i roto i %s: '%s'</translation>
    </message>
    <message>
        <source>Listening for incoming connections failed (listen returned error %s)</source>
        <translation type="unfinished">Whakararuraru ana te whakarongo i ngā hononga e haere mai ana (kua whakahokia te hapa %s)</translation>
    </message>
    <message>
        <source>Loading P2P addresses…</source>
        <translation type="unfinished">Whakararuraru P2P addresses ...</translation>
    </message>
    <message>
        <source>Loading banlist…</source>
        <translation type="unfinished">Whakararuraru ana, ka whakapau kaha ki te whakamāori i te kupu whakamāoritanga.</translation>
    </message>
    <message>
        <source>Loading block index…</source>
        <translation type="unfinished">Whakaritea te rārangi whakaputa...</translation>
    </message>
    <message>
        <source>Loading wallet…</source>
        <translation type="unfinished">Whakararuraru pūtea...</translation>
    </message>
    <message>
        <source>Missing amount</source>
        <translation type="unfinished">Te moni i ngaro</translation>
    </message>
    <message>
        <source>Missing solving data for estimating transaction size</source>
        <translation type="unfinished">Kua ngaro ngā raraunga whakatikatika mō te whakarite i te rahi whakaritenga whakawhiti</translation>
    </message>
    <message>
        <source>Need to specify a port with -whitebind: '%s'</source>
        <translation type="unfinished">Me whakarite i tētahi pōti me te -whitebind: '%s'</translation>
    </message>
    <message>
        <source>No addresses available</source>
        <translation type="unfinished">Kāore he wāhitau wātea</translation>
    </message>
    <message>
        <source>Rescanning…</source>
        <translation type="unfinished">Whakarerekētia...</translation>
    </message>
    <message>
        <source>SQLiteDatabase: Failed to execute statement to verify database: %s</source>
        <translation type="unfinished">SQLiteDatabase: Kua whakakorehia te whakahaere i te kōrero hei whakamana i te papakupu: %s</translation>
    </message>
    <message>
        <source>SQLiteDatabase: Failed to prepare statement to verify database: %s</source>
        <translation type="unfinished">SQLiteDatabase: Kua whakakorehia te whakarite i te kupu hei whakamāmā i te papakupu: %s</translation>
    </message>
    <message>
        <source>SQLiteDatabase: Failed to read database verification error: %s</source>
        <translation type="unfinished">SQLiteDatabase: Kua whakapau kaha te pānui i te hapa whakamātau o te papamahi: %s</translation>
    </message>
    <message>
        <source>SQLiteDatabase: Unexpected application id. Expected %u, got %u</source>
        <translation type="unfinished">SQLiteDatabase: Tino whakararuraru te tuhinga whakamahi. Tūpono %u, ka whiwhi %u</translation>
    </message>
    <message>
        <source>Section [%s] is not recognized.</source>
        <translation type="unfinished">Kāore i whakaaetia te wāhanga [%s].</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation type="unfinished">Ko te whakakore i te whakauru i te whakaritenga</translation>
    </message>
    <message>
        <source>Specified -walletdir "%s" does not exist</source>
        <translation type="unfinished">Kāore i te whiwhi i te -walletdir i whakaritea "%s"</translation>
    </message>
    <message>
        <source>Specified -walletdir "%s" is not a directory</source>
        <translation type="unfinished">Kāore i te whare tūmatanui te -walletdir i whakaritea "%s"</translation>
    </message>
    <message>
        <source>Specified blocks directory "%s" does not exist.</source>
        <translation type="unfinished">Kāore te whare pūranga i whakaritea "%s" e whai wāhi.</translation>
    </message>
    <message>
        <source>Specified data directory "%s" does not exist.</source>
        <translation type="unfinished">Kāore te whare pūranga raraunga i whakaritea "%s" i te whiwhi.</translation>
    </message>
    <message>
        <source>Starting network threads…</source>
        <translation type="unfinished">Whakamāori i te tekau whakahaere whatunga...</translation>
    </message>
    <message>
        <source>The source code is available from %s.</source>
        <translation type="unfinished">Ko te kōnae pūnaha e wātea ana i te %s.</translation>
    </message>
    <message>
        <source>The specified config file %s does not exist</source>
        <translation type="unfinished">Kāore te kōnae whirihoranga i whiwhi i te %s i te wā e whakapau kore ana</translation>
    </message>
    <message>
        <source>The transaction amount is too small to pay the fee</source>
        <translation type="unfinished">Ko te moni whakaritenga he iti rawa hei utu i te utu</translation>
    </message>
    <message>
        <source>The wallet will avoid paying less than the minimum relay fee.</source>
        <translation type="unfinished">Ka whakakore te pōkeka i te utu iti ake i te utu tawhiti i te iti rawa.</translation>
    </message>
    <message>
        <source>This is experimental software.</source>
        <translation type="unfinished">He mea whakamātautau tēnei pūmanawa.</translation>
    </message>
    <message>
        <source>This is the minimum transaction fee you pay on every transaction.</source>
        <translation type="unfinished">Ko tēnei te utu whakaritenga iti rawa ka whiwhi koe i ia whakaritenga.</translation>
    </message>
    <message>
        <source>This is the transaction fee you will pay if you send a transaction.</source>
        <translation type="unfinished">Ko te utu whakawhiti tāuta tēnei ka utu e whiwhi ana koe ki te tuku i tētahi tāuta.</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation type="unfinished">He iti rawa te moni whakaritenga</translation>
    </message>
    <message>
        <source>Transaction amounts must not be negative</source>
        <translation type="unfinished">Kāore e whakaaetia ngā moni whakaritenga kia whakararuraru.</translation>
    </message>
    <message>
        <source>Transaction change output index out of range</source>
        <translation type="unfinished">He whakawhitiwhitinga whakaputanga hōputu whakararuraru te tūnga</translation>
    </message>
    <message>
        <source>Transaction must have at least one recipient</source>
        <translation type="unfinished">Me whiwhi whakaritenga tātari tētahi whiwhi whakaritenga ki te kaiwhiwhi kotahi i te minimuma</translation>
    </message>
    <message>
        <source>Transaction needs a change address, but we can't generate it.</source>
        <translation type="unfinished">He hiahia te whakarerekē i te whakaritenga whakaritenga, engari kāore e taea e mātou te whakaputa.</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation type="unfinished">He whakawhitiwhitinga nui rawa te whakapau kaha</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %s)</source>
        <translation type="unfinished">Kāore e taea te whakakōtuitui ki %s i tēnei rorohiko (kua whakahoki te whakakōtuitui i te hapa %s)</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer. %s is probably already running.</source>
        <translation type="unfinished">Kāore e taea te whakakōtuitui ki %s i tēnei rorohiko. E whakapau kē ana te %s e whakahaere ana.</translation>
    </message>
    <message>
        <source>Unable to create the PID file '%s': %s</source>
        <translation type="unfinished">Kāore e taea te hanga i te kōnae PID '%s': %s</translation>
    </message>
    <message>
        <source>Unable to find UTXO for external input</source>
        <translation type="unfinished">Kāore i te kite i te UTXO mō te whakauru ā-waho</translation>
    </message>
    <message>
        <source>Unable to open %s for writing</source>
        <translation type="unfinished">Kāore e taea te whakatuwhera i %s hei tuhi</translation>
    </message>
    <message>
        <source>Unable to parse -maxuploadtarget: '%s'</source>
        <translation type="unfinished">Kāore e taea te whakamāori i te -maxuploadtarget: '%s'</translation>
    </message>
    <message>
        <source>Unable to start HTTP server. See debug log for details.</source>
        <translation type="unfinished">Kāore e taea te whakahohe i te tūmau HTTP. Tirohia te rārangi whakararuraru mō ngā whakamārama.</translation>
    </message>
    <message>
        <source>Unknown -blockfilterindex value %s.</source>
        <translation type="unfinished">-He mea kore te -blockfilterindex whiwhi %s.</translation>
    </message>
    <message>
        <source>Unknown address type '%s'</source>
        <translation type="unfinished">He aha te momo wāhitau kore mō '%s'</translation>
    </message>
    <message>
        <source>Unknown change type '%s'</source>
        <translation type="unfinished">He whakararuraru, he momo hēhē '%s'</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation type="unfinished">He whakamāoritia te tekau whakamāoritanga:
'Unknown network specified in -onlynet: '%s''</translation>
    </message>
    <message>
        <source>Unknown new rules activated (versionbit %i)</source>
        <translation type="unfinished">He whakapau kaha hōu kua whakakāhoretia (wāhanga %i)</translation>
    </message>
    <message>
        <source>Unsupported logging category %s=%s.</source>
        <translation type="unfinished">Kāore i te tautoko te kāwai rorohiko %s=%s</translation>
    </message>
    <message>
        <source>User Agent comment (%s) contains unsafe characters.</source>
        <translation type="unfinished">Te korero a te kaihoko (%s) e whakararuraru ana i ngā tohu kore whakapau kaha.</translation>
    </message>
    <message>
        <source>Verifying blocks…</source>
        <translation type="unfinished">Whakamāramatia ngā paraka...</translation>
    </message>
    <message>
        <source>Verifying wallet(s)…</source>
        <translation type="unfinished">Whakamātau i te wharepukapuka...</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart %s to complete</source>
        <translation type="unfinished">Me whakakore i te whare moni: whakamatau i te %s hei whakakore i te whakamutunga</translation>
    </message>
    <message>
        <source>Settings file could not be read</source>
        <translation type="unfinished">Kāore i taea te pānui i te kōnae tautuhinga</translation>
    </message>
    <message>
        <source>Settings file could not be written</source>
        <translation type="unfinished">Kāore i taea te tuhi i te kōnae tautuhinga</translation>
    </message>
</context>
</TS>